@@ -39,9 +39,13 @@ checkFormula <- function(formula, data, analysis){
   dv = stringFromFormula(formula[[2]])
   
   if(!is.numeric(data[,dv])) stop("Dependent variable must be numeric.")
+  if(any(is.na(data[,dv]))) stop("Dependent variable must not contain missing values.")
   factors = fmlaFactors(formula, data)
   terms = colnames(attr(terms(formula, data = data),"factors"))  
   
+  vars = rownames(attr(terms(formula, data = data),"factors")) 
+  if(any(is.na(data[,vars]))) stop("Predictors must not contain missing values.")
+  
   if(is.null(factors)) return()
   if(factors[1] %in% terms) stop("Dependent variable cannot be a predictor.")
   if(!all(factors %in% cnames)) stop("Some variables missing in data frame.")
@@ -54,9 +58,11 @@ checkFormula <- function(formula, data, analysis){
   if(analysis=="lm" | analysis=="anova" | analysis == "regression" | analysis == "indept")
     if(attr(terms(formula, data = data),"intercept") == 0) stop("Formula must include intercept.")            
   
-  if(analysis=="indept")
-    if( length(factors)>2 ) stop("Indep. groups t test can only support 1 factor as predictor.")  
-  
+  if(analysis=="indept"){
+    if( length(terms) > 1 ) stop("Indep. groups t test can only support 1 factor as predictor.")  
+    if(length(grep(":",terms,fixed=TRUE))) stop("Interaction terms are not allowed in t test.")
+    if(nlevels(factor(data[,terms])) > 2) stop("Indep. groups t test requires a factor with exactly 2 levels.")
+  }
   invisible()
 }
 
