@@ -12,18 +12,22 @@ enumerateGeneralModels = function(fmla, whichModels, neverExclude=NULL,includeBo
   logicalToInclude = filterVectorLogical(neverExclude,trms)
   if(any(logicalToInclude)){
     alwaysIncluded = trms[logicalToInclude]
-    rq = matrix(outer(trms,alwaysIncluded,requiredFor),nrow=length(trms))
-    rq = apply(rq,1,any)
-    logicalToInclude[rq] = TRUE 
-    alwaysIncluded = unique(c(trms[rq], alwaysIncluded))
+    if(whichModels=="withMain"){
+      rq = matrix(outer(trms,alwaysIncluded,requiredFor),nrow=length(trms))
+      rq = apply(rq,1,any)
+      logicalToInclude[rq] = TRUE 
+      alwaysIncluded = unique(c(trms[rq], alwaysIncluded))
+    }
     alwaysIncludedString = paste(alwaysIncluded,collapse=" + ")
   }
   trms =  trms[!logicalToInclude]
   
   ntrms <- length(trms)
   dv = stringFromFormula(fmla[[2]])
+  if(ntrms == 0 )  return(list(fmla))
   if(ntrms == 1 ) whichModels = "all"
   
+  
   if(whichModels=="top"){
     lst = combn2( trms, ntrms - 1 )
   }else if(whichModels=='bottom'){
@@ -94,7 +98,7 @@ possibleRestrictionsWithMainGeneral <- function(trms, alwaysKept=NULL){
   if(nFactors>options()$BFfactorsMax){
     warning("Falling back to slow recursive method of enumerating models due to many factors.")
     retList = possibleRestrictionsWithMainGeneralFallback(trms, alwaysKept)
-    return(list(retList,trms))
+    return(c(retList,list(trms)))
   }
   
   myTerms = sapply(1:(2^nFactors-1),makeTerm,factors=myFactors)
