@@ -9,6 +9,15 @@ BFmodel <- function(type, identifier, prior, dataTypes, shortName, longName){
       version = BFInfo(FALSE))
 }
 
+BFcontingencyTable <- function(type, identifier, prior, shortName, longName){
+  new("BFcontingencyTable", type = type,
+      identifier = identifier,
+      prior = prior,
+      shortName = shortName,
+      longName = longName,
+      version = BFInfo(FALSE))
+}
+
 BFlinearModel <- function(type, identifier, prior, dataTypes, shortName, longName){
   new("BFlinearModel", type = type,
       identifier = identifier,
@@ -37,6 +46,15 @@ BFindepSample <- function(type, identifier, prior, shortName, longName){
       version = BFInfo(FALSE))
 }
 
+BFmetat <- function(type, identifier, prior, shortName, longName){
+  new("BFmetat", type = type,
+      identifier = identifier,
+      prior = prior,
+      shortName = shortName,
+      longName = longName,
+      version = BFInfo(FALSE))
+}
+
 #######
 
 setMethod('show', signature = c("BFlinearModel"),
@@ -50,6 +68,15 @@ setMethod('show', signature = c("BFlinearModel"),
   }
 )
 
+setMethod('show', signature = c("BFmetat"),
+          function(object){
+            cat("---\n Model:\n")
+            cat("Type: ",class(object)[1],", ",object@type,"\n",sep="")
+            cat(object@longName,"\n")
+            cat("\n\n")
+          }
+)
+
 setMethod("%same%", signature = c(x="BFmodel",y="BFmodel"),
           function(x,y){
             classesSame = identical(class(x),class(y))
@@ -203,5 +230,101 @@ setMethod('compare', signature(numerator = "BFindepSample", denominator = "missi
           })
           
 
+setMethod('compare', signature(numerator = "BFmetat", denominator = "missing", data = "data.frame"), 
+          function(numerator, data, ...){
+            
+            nullInterval=numerator@prior$nullInterval
+
+            if( (numerator@type=="JZS") ){
+              
+                bf = meta.ttest.tstat(t=data$t, n1=data$n1, n2=data$n2, 
+                                      nullInterval=nullInterval, rscale=numerator@prior$rscale)
+                numBF = bf[['bf']]
+                errorEst = bf[['properror']]
+  
+              if(!is.null(nullInterval)){
+                
+                modComplement = numerator
+                modComplement@shortName = paste("Alt., r=",round(numerator@prior$rscale,3)," !(",nullInterval[1],"<d<",nullInterval[2],")",sep="")
+                modComplement@longName = paste("Alternative, r = ",numerator@prior$rscale," !(",nullInterval[1],"<d<",nullInterval[2],")",sep="")
+                
+                numList = list(numerator,modComplement)
+                nms = c(numerator@shortName,modComplement@shortName)
+              }else{
+                numList = list(numerator)
+                nms = numerator@shortName
+              }
+              modDenominator = BFmetat(type = "JZS", 
+                                           identifier = list(formula = "d = 0"), 
+                                           prior=list(),
+                                           shortName = "Null, d=0",
+                                           longName = "Null, d = 0")
+              
+              bf_df = data.frame(bf = numBF,
+                                 error = errorEst,
+                                 time = date(),
+                                 code = randomString(length(numBF)))
+              
+              rownames(bf_df) <- nms
+              
+              newBF = BFBayesFactor(numerator = numList,
+                                    denominator = modDenominator,
+                                    data = data,
+                                    bayesFactor = bf_df)
+              return(newBF)
+            }else{
+              stop("Unknown prior type: ", numerator@type)
+            }
+          })
 
 
+setMethod('compare', signature(numerator = "BFcontingencyTable", denominator = "missing", data = "data.frame"), 
+          function(numerator, data, ...){
+            
+            type = numerator@type
+            a = numerator@prior$a
+            
+            if(any(data%%1 != 0)) stop("All elements of x must be integers.")
+            if(any(dim(data)<2) | (length(dim(data)) != 2)) stop("x must be m by n.")
+            
+            lbf = switch(type,
+                         "poisson" = contingencyPoisson(as.matrix(data), a),
+                         "joint multinomial" = contingencyJointMultinomial(as.matrix(data), a),
+                         "independent multinomial" = contingencyIndepMultinomial(as.matrix(data), a),
+                         "hypergeometric" =  contingencyHypergeometric(as.matrix(data), a),
+                         stop("Unknown value of sampleType (see help for contingencyBF).")
+            )
+            error = 0
+            
+            denominator = BFcontingencyTable(type = type, 
+                                             identifier = list(formula = "independence"), 
+                                             prior=list(),
+                                             shortName = "Indep.",
+                                             longName = "Null, independence")
+            
+            bf_df = data.frame(bf = lbf,
+                               error = error,
+                               time = date(),
+                               code = randomString(1))
+            
+            rownames(bf_df) <- numerator@shortName
+            
+            newBF = BFBayesFactor(numerator = list(numerator),
+                                  denominator = denominator,
+                                  data = as.data.frame(data),
+                                  bayesFactor = bf_df
+            )
+            return(newBF)
+
+})
+
+setMethod('compare', signature(numerator = "BFcontingencyTable", denominator = "BFcontingencyTable", data = "data.frame"), 
+          function(numerator, denominator, data, ...){
+            if(!identical(numerator@type, denominator@type)) stop("Models of different types cannot be currently be compared by compare().")
+            if(!identical(class(numerator), class(denominator))) stop("Models of different classes cannot be currently be compared by compare().")
+                        
+            BFnum = compare(numerator = numerator, data = data)              
+            BFden = compare(numerator = denominator, data = data)
+            return(BFnum / BFden)
+          })
+
