@@ -16,9 +16,8 @@
 ##' below for more details.
 ##' 
 ##' For the \code{rscale} argument, several named values are recognized: 
-##' "medium", "wide", and "ultrawide". For the one-sample test, these correspond 
-##' to \eqn{r} scale values of 1/2, \eqn{\sqrt{2}/2}{sqrt(2)/2}, and 1, respectively. For the two-sample 
-##' test, they correspond to \eqn{\sqrt{2}/2}{sqrt(2)/2}, 1, and \eqn{\sqrt{2}/2}{sqrt(2)}
+##' "medium", "wide", and "ultrawide". These correspond 
+##' to \eqn{r} scale values of \eqn{\sqrt{2}/2}{sqrt(2)/2}, 1, and \eqn{\sqrt{2}}{sqrt(2)} 
 ##' respectively.
 ##' 
 ##' The Bayes factor is computed via Gaussian quadrature.
@@ -38,6 +37,7 @@
 ##'   strings; see Details.
 ##' @param posterior if \code{TRUE}, return samples from the posterior instead 
 ##'   of Bayes factor
+##' @param callback callback function for third-party interfaces 
 ##' @param ... further arguments to be passed to or from methods.
 ##' @return If \code{posterior} is \code{FALSE}, an object of class 
 ##'   \code{BFBayesFactor} containing the computed model comparisons is 
@@ -65,7 +65,7 @@
 ##'   Perception and Cognition Lab (University of Missouri): Bayes factor 
 ##'   calculators. \url{http://pcl.missouri.edu/bayesfactor}
 ##' @note The default priors have scale has changed from 1 to \eqn{\sqrt{2}/2}. The 
-##'   factor of \eqn{\sqrt{2}} in the two-sample t test is to be consistent 
+##'   factor of \eqn{\sqrt{2}}  is to be consistent 
 ##'   with Morey et al. (2011) and 
 ##'   Rouder et al. (2012), and the factor of \eqn{1/2} in both is to better scale the 
 ##'   expected effect sizes; the previous scaling put more weight on larger 
@@ -86,9 +86,20 @@
 ##' plot(samples[,"mu"])
 ##' @seealso \code{\link{integrate}}, \code{\link{t.test}}
 
-ttestBF <- function(x, y = NULL, formula = NULL, mu = 0, nullInterval = NULL, 
-                    paired = FALSE, data = NULL, rscale="medium", posterior=FALSE, ...){
+
+ttestBF <- function(x = NULL, y = NULL, formula = NULL, mu = 0, nullInterval = NULL, 
+                    paired = FALSE, data = NULL, rscale="medium", posterior=FALSE, callback = function(...) as.integer(0), ...){
   
+  if(!is.null(x) & !is.null(formula)) stop("Only one of x or formula should be defined.")
+  
+  if(!is.null(x) | !is.null(y))
+    if(any(is.na(c(x,y)))) stop("x or y must not contain missing values.")
+  
+  if(!is.null(nullInterval)){
+    if(identical(nullInterval,c(-Inf,Inf))){
+      nullInterval = NULL
+    }
+  }
   
   if( (is.null(formula) & is.null(y)) | (!is.null(y) & paired) ){
     if(paired){
@@ -106,7 +117,7 @@ ttestBF <- function(x, y = NULL, formula = NULL, mu = 0, nullInterval = NULL,
       )
       
       if(posterior){
-        chains = posterior(modFull,data = data.frame(y=x), ...)
+        chains = posterior(modFull,data = data.frame(y=x), callback = callback, ...)
         return(chains)
       }else{
         bf = compare(numerator = modFull, data = data.frame(y=x))
@@ -121,7 +132,7 @@ ttestBF <- function(x, y = NULL, formula = NULL, mu = 0, nullInterval = NULL,
                                  longName = paste("Alternative, r = ",rscale,", mu =/= ",mu, " ",nullInterval[1],"<d<",nullInterval[2],sep="")
       )      
       if(posterior){
-        chains = posterior(modInterval, data = data.frame(y=x), ...)
+        chains = posterior(modInterval, data = data.frame(y=x), callback = callback, ...)
         return(chains)
       }else{
         bf = compare(numerator = modInterval, data = data.frame(y=x))
@@ -137,11 +148,10 @@ ttestBF <- function(x, y = NULL, formula = NULL, mu = 0, nullInterval = NULL,
   if(!is.null(formula)){ # formula
     if(paired) stop("Cannot use 'paired' with formula.")
     if(is.null(data)) stop("'data' needed for formula.")
-    
-    ivs = attr(terms(formula, data = data),"term.labels")
-    if(length(ivs) > 1) stop("Only one independent variable allowed for t test.")
+    checkFormula(formula, data, analysis = "indept")
+
     dataTypes = "fixed"
-    names(dataTypes) = ivs
+    names(dataTypes) =  attr(terms(formula, data = data),"term.labels")
     if(mu != 0) stop("Use of nonzero null hypothesis not implemented for independent samples test.")
     
     rscale = rpriorValues("ttestTwo",,rscale)
@@ -164,7 +174,7 @@ ttestBF <- function(x, y = NULL, formula = NULL, mu = 0, nullInterval = NULL,
     }
 
     if(posterior){
-      chains = posterior(numerator, data = data, ...)
+      chains = posterior(numerator, data = data, callback = callback, ...)
       return(chains)
     }else{
       bf = compare(numerator = numerator, data = data)
